%global pypi_name magic-wormhole-transit-relay

%global common_description %{expand:
This package contains the Magic-Wormhole "Transit Relay", a server that
helps clients establish bulk-data transit connections even when both are
behind NAT boxes. Each side makes a TCP connection to this server and
presents a handshake. Two connections with identical handshakes are
glued together, allowing them to pretend they have a direct connection.

This server used to be included in the magic-wormhole repository, but
was split out into a separate repo to aid deployment and development.}

Name:           python-%{pypi_name}
Summary:        Transit Relay server for Magic-Wormhole
Version:        0.4.0
Release:        1%{?dist}
License:        MIT

URL:            https://github.com/warner/magic-wormhole-transit-relay
Source0:        %{pypi_source}

BuildArch:      noarch

BuildRequires:  python3-devel

%description %{common_description}


%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name} %{common_description}


%prep
%autosetup -n %{pypi_name}-%{version}

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

%generate_buildrequires
%pyproject_buildrequires -x dev

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files wormhole_transit_relay

%check
%pyproject_check_import
# Fedora tox macro does not have correct settings for this package
# package uses  twisted testing framework
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.common
# Test below fails, needs internet access
#{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_backpressure
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_config
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_database
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_rlimits
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_service
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_stats
%{py3_test_envvars} %{python3} -m twisted.trial wormhole_transit_relay.test.test_transit_server


%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.md
%doc docs/
# Need to co-own twisted directory for plugin
%{python3_sitelib}/twisted/plugins/*

%changelog
* Tue Nov 19 2024 Petr Menšík <pemensik@redhat.com> - 0.4.0-1
- Update to 0.4.0

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.2.1-5
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.2.1-2
- Rebuilt for Python 3.9

* Sun Apr 05 2020 Fabio Valentini <decathorpe@gmail.com> - 0.2.1-1
- Update to version 0.2.1.

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 0.1.2-5
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.1.2-4
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Nov 21 2018 Fabio Valentini <decathorpe@gmail.com> - 0.1.2-1
- Initial package.

